aboutsummaryrefslogtreecommitdiff
path: root/R
diff options
context:
space:
mode:
authoranabranch <wac.chambers@gmail.com>2017-01-08 20:37:46 -0800
committerFelix Cheung <felixcheung@apache.org>2017-01-08 20:37:46 -0800
commit19d9d4c855eab8f647a5ec66b079172de81221d0 (patch)
tree3bad937b8bc7929af833c749c68aab8b32c51379 /R
parent1f6ded6455d07ec8828fc9662ddffe55cbba4238 (diff)
downloadspark-19d9d4c855eab8f647a5ec66b079172de81221d0.tar.gz
spark-19d9d4c855eab8f647a5ec66b079172de81221d0.tar.bz2
spark-19d9d4c855eab8f647a5ec66b079172de81221d0.zip
[SPARK-19126][DOCS] Update Join Documentation Across Languages
## What changes were proposed in this pull request? - [X] Make sure all join types are clearly mentioned - [X] Make join labeling/style consistent - [X] Make join label ordering docs the same - [X] Improve join documentation according to above for Scala - [X] Improve join documentation according to above for Python - [X] Improve join documentation according to above for R ## How was this patch tested? No tests b/c docs. Please review http://spark.apache.org/contributing.html before opening a pull request. Author: anabranch <wac.chambers@gmail.com> Closes #16504 from anabranch/SPARK-19126.
Diffstat (limited to 'R')
-rw-r--r--R/pkg/R/DataFrame.R19
1 files changed, 11 insertions, 8 deletions
diff --git a/R/pkg/R/DataFrame.R b/R/pkg/R/DataFrame.R
index 7737ffe4ed..c56648a8c4 100644
--- a/R/pkg/R/DataFrame.R
+++ b/R/pkg/R/DataFrame.R
@@ -2313,9 +2313,9 @@ setMethod("dropDuplicates",
#' @param joinExpr (Optional) The expression used to perform the join. joinExpr must be a
#' Column expression. If joinExpr is omitted, the default, inner join is attempted and an error is
#' thrown if it would be a Cartesian Product. For Cartesian join, use crossJoin instead.
#' @param joinType The type of join to perform. The following join types are available:
#' 'inner', 'outer', 'full', 'fullouter', leftouter', 'left_outer', 'left',
#' 'right_outer', 'rightouter', 'right', and 'leftsemi'. The default joinType is "inner".
#' @return A SparkDataFrame containing the result of the join operation.
#' @family SparkDataFrame functions
#' @aliases join,SparkDataFrame,SparkDataFrame-method
@@ -2344,15 +2344,18 @@ setMethod("join",
if (is.null(joinType)) {
sdf <- callJMethod(x@sdf, "join", y@sdf, joinExpr@jc)
} else {
- if (joinType %in% c("inner", "outer", "full", "fullouter",
- "leftouter", "left_outer", "left",
- "rightouter", "right_outer", "right", "leftsemi")) {
+ if (joinType %in% c("inner", "cross",
+ "outer", "full", "fullouter", "full_outer",
+ "left", "leftouter", "left_outer",
+ "right", "rightouter", "right_outer",
+ "left_semi", "leftsemi", "left_anti", "leftanti")) {
joinType <- gsub("_", "", joinType)
sdf <- callJMethod(x@sdf, "join", y@sdf, joinExpr@jc, joinType)
} else {
stop("joinType must be one of the following types: ",
- "'inner', 'outer', 'full', 'fullouter', 'leftouter', 'left_outer', 'left',
- 'rightouter', 'right_outer', 'right', 'leftsemi'")
+ "'inner', 'cross', 'outer', 'full', 'full_outer',",
+ "'left', 'left_outer', 'right', 'right_outer',",
+ "'left_semi', or 'left_anti'.")
}
}
}
@@ -2313,9 +2313,9 @@ setMethod("dropDuplicates",
#' Column expression. If joinExpr is omitted, the default, inner join is attempted and an error is
#' thrown if it would be a Cartesian Product. For Cartesian join, use crossJoin instead.
-#' @param joinType The type of join to perform. The following join types are available:
-#' 'inner', 'outer', 'full', 'fullouter', leftouter', 'left_outer', 'left',
-#' 'right_outer', 'rightouter', 'right', and 'leftsemi'. The default joinType is "inner".
+#' @param joinType The type of join to perform, default 'inner'.
+#' Must be one of: 'inner', 'cross', 'outer', 'full', 'full_outer',
+#' 'left', 'left_outer', 'right', 'right_outer', 'left_semi', or 'left_anti'.
#' @return A SparkDataFrame containing the result of the join operation.
#' @family SparkDataFrame functions